;; Custom GNU Guix Package for ikiwiki
(define-module (cube packages ikiwiki)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module (guix build-system perl)
  #:use-module ((guix licenses) #:prefix l:)
  #:use-module (gnu packages python)
  #:use-module (gnu packages web)
  #:use-module (gnu packages perl)
  #:use-module (gnu packages imagemagick)
  #:use-module (gnu packages markup)
  #:use-module (gnu packages databases)
  #:use-module (gnu packages base)
  #:use-module (gnu packages xml)
  #:use-module (gnu packages gettext)
  #:use-module (gnu packages version-control))

(define-public perl-cgi-formbuilder
  (package
  (name "perl-cgi-formbuilder")
  (version "3.10")
  (source
    (origin
      (method url-fetch)
      (uri (string-append
             "mirror://cpan/authors/id/B/BI/BIGPRESH/CGI-FormBuilder-"
             version
             ".tar.gz"))
      (sha256
        (base32
          "163ixq9kninqq094z2rnkg9pv3bcmvjphlww4vksfrzhq3h9pjdf"))))
  (build-system perl-build-system)
  (inputs `(("perl-cgi" ,perl-cgi)))
  (home-page
    "http://search.cpan.org/dist/CGI-FormBuilder")
  (synopsis
    "Easily generate and process stateful forms")
  (description "")
  (license #f)))

(define-public ikiwiki
  (package
    (name "ikiwiki")
    (version "3.20170111")
    (source
     (origin
       (method url-fetch)
       (uri (string-append "http://snapshot.debian.org/archive/debian/"
                           "20170111T215449Z/pool/main/i/ikiwiki/ikiwiki_"
                           version ".tar.xz"))
       (sha256
        (base32
         "00d7yzv426fvqbhvzyafddv7fa6b4j2647b0wi371wd5yjj9j3sz"))))
    (build-system perl-build-system)
    (arguments
     `(;; Image tests fail
       ;;
       ;; Test Summary Report
       ;; -------------------
       ;; t/img.t                      (Wstat: 2304 Tests: 62 Failed: 9)
       ;;   Failed tests:  21, 27-28, 30-35
       ;;   Non-zero exit status: 9
       #:tests? #f
       #:phases
       (modify-phases %standard-phases
         (add-after 'unpack 'include-PERL5LIB-in-wrapper
           (lambda _
             (substitute* "IkiWiki/Wrapper.pm"
               (("^@wrapper\\_hooks")
                (string-append
                 "@wrapper_hooks\n"
                 "        addenv(\"PERL5LIB\", \""
                 (getenv "PERL5LIB")
                 "\");")))))
         (add-after 'install 'wrap-programs
           (lambda* (#:key outputs #:allow-other-keys)
             (let* ((out  (assoc-ref outputs "out"))
                    (bin  (string-append out "/bin/"))
                    (path (getenv "PERL5LIB")))
               (for-each (lambda (file)
                           (wrap-program file
                             `("PERL5LIB" ":" prefix (,path))))
                         (find-files bin))
               #t))))))
    (native-inputs
     `(("which" ,which)
       ("perl-html-tagset" ,perl-html-tagset)
       ("perl-timedate" ,perl-timedate)
       ("perl-xml-sax" ,perl-xml-sax)
       ("perl-xml-simple" ,perl-xml-simple)
       ("gettext" ,gettext-minimal)
       ("subversion" ,subversion)
       ("git" ,git)
       ("bazaar" ,bazaar)
       ("cvs" ,cvs)
       ("mercurial" ,mercurial)))
    (inputs
     `(("python" ,python-wrapper)
       ("perl-cgi-session" ,perl-cgi-session)
       ("perl-cgi-simple" ,perl-cgi-simple)
       ("perl-json" ,perl-json)
       ("perl-image-magick" ,perl-image-magick)
       ("perl-uri" ,perl-uri)
       ("perl-html-parser" ,perl-html-parser)
       ("perl-uri" ,perl-uri)
       ("perl-text-markdown-discount" ,perl-text-markdown-discount)
       ("perl-html-scrubber" ,perl-html-scrubber)
       ("perl-html-template" ,perl-html-template)
       ("perl-yaml-libyaml" ,perl-yaml-libyaml)))
    (propagated-inputs
     `(("perl-http-message" ,perl-http-message)
       ("perl-libwww" ,perl-libwww)
       ("perl-uri", perl-uri)
       ("perl-db-file", perl-db-file)
       ("perl-cgi-formbuilder", perl-cgi-formbuilder)
       ("perl-html-tree", perl-html-tree)))
    (home-page "https://ikiwiki.info/")
    (synopsis "Wiki compiler, capable of generating HTML")
    (description
     "Ikiwiki is a wiki compiler, capable of generating a static set of web
pages, but also incorporating dynamic features like a web based editor andb
commenting.")
    (license l:gpl2+)))
